#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# negmas documentation build configuration file, created by
# sphinx-quickstart on Fri Jun  9 13:47:02 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it
# absolute, like shown here.
#
import os
import sys
# sys.path.insert(0, os.path.abspath('..')) # only import from installed version using pip install -e

import negmas
from negmas import *
from negmas.situated import *
from negmas.apps.scml import *

# import guzzle_sphinx_theme
import sphinx_rtd_theme
import recommonmark.parser

# -- General configuration ---------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.viewcode',
              'sphinx.ext.coverage',
              'sphinxcontrib.napoleon',
              'sphinx.ext.mathjax',
              'sphinx.ext.githubpages',
              'sphinx.ext.graphviz',
              'sphinx_autodoc_annotation',
              'sphinx_autodoc_typehints',
              'sphinx.ext.autosummary',
              'guzzle_sphinx_theme',
              'sphinx_automodapi.automodapi',
              'sphinx.ext.intersphinx',
              'sphinx_automodapi.smart_resolver',
              'sphinxcontrib.fulltoc',
              'nb2plots',
              ]

intersphinx_mapping = {'python': ('http://docs.python.org/3', None),
                       'numpy': ('http://docs.scipy.org/doc/numpy/', None),
                       'scipy': ('http://docs.scipy.org/doc/scipy/reference/', None),
                       # 'matplotlib': ('http://matplotlib.sourceforge.net/', None),
                       }

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
source_suffix = ['.rst', '.md']
#source_suffix = '.rst'
source_parsers = {'.md': 'recommonmark.parser.CommonMarkParser'}

# The strategy toctree document.
master_doc = 'index'

# General information about the project.
project = u'negmas'
copyright = u"2018, Yasser Mohammad"
author = u"Yasser Mohammad"

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.
#
# The short X.Y version.
version = negmas.__version__
# The full version, including alpha/cost/rc tags.
release = negmas.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'classic'
# html_theme = 'alabaster'
#html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_theme = "sphinx_rtd_theme"
html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
# theme options for sphinx_rtd_theme
html_theme_options = {
    # 'typekit_id': 'hiw1hhg',
    #'canonical_url':
    #'analytics_id':
    'collapse_navigation': False,
    'sticky_navigation': False,
    'navigation_depth': 4,
    'includehidden': True,
    #'logo_only':
    'display_version': True,
    'prev_next_buttons_location': 'bottom',
    # 'titles_only': False
}

# theme options for alabaster
# html_theme_options = {
#     'show_relbars': True,
#     'show_related': True,
#
# }

# -- Options for HTMLHelp output ---------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'negotiatedoc'


# -- Options for LaTeX output ------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    'papersize': 'a4paper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'negmas.tex',
     u'negmas Documentation',
     u'Yasser Mohammad', 'manual'),
]


# -- Options for manual page output ------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'negmas',
     u'negmas Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'negmas',
     u'negmas Documentation',
     author,
     'negmas',
     'Situated Simultaneous Negotiations Library.',
     'Miscellaneous'),
]

default_role = 'any'

imgmath_image_format = 'png'


# If false, no module index is generated.
html_domain_indices = False

